# apckey25

[![PyPI - Version](https://img.shields.io/pypi/v/apckey25)](https://pypi.org/project/apckey25)

> A simple python interface to interact with the AKAI APC Key 25

## Getting started

First install the package. It is published also on PyPI.
For usage, please consult the examples and code for now.
